/***************************************************************************
    file:           generalcfgdesign.h
    description:    general configuration design
    begin:          09/06/2024
    Copyright:      Giuseppe Della Bianca<giusdbg@gmail.com>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GENERALCFGDESIGN_H
#define GENERALCFGDESIGN_H

#include <qvariant.h>
#include <qwidget.h>
#include <qlabel.h>
#include <qspinbox.h>
#include <qslider.h>
#include <qtabwidget.h>
#include <qcombobox.h>

#include "ksensorsmain.h"


class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QButtonGroup;
class QRadioButton;
class QGroupBox;
class QCheckBox;

class GeneralCfgDesign : public QWidget
{
    Q_OBJECT

public:
    GeneralCfgDesign( KsensorsMain *ksensorsMainIn, QWidget *parent = nullptr, const QString &name = QString(), Qt::WindowFlags fl = Qt::Widget );
    ~GeneralCfgDesign();

    QGroupBox* boxGeneralPalette;
    QGroupBox* GroupBox2;
    QCheckBox* CheckBoxAutoStart;

protected:
    
    QTabWidget *qtwMain;
    QWidget *qwAppear;
    QWidget *qwPref;
    
    QGroupBox* qgbMeterAppear;
    QGridLayout* qglMeterAppear;    
    QLabel *qlGaugeSize;
    QLabel *qlChartSize;
    QLabel *qlChartSizeSep;
    QComboBox *qcbGaugeSize;
    QComboBox *qcbChartWidth;
    QComboBox *qcbChartHeight;

    QGroupBox* qgbPanelOpacity;
    QHBoxLayout* qhblPanelOpacity;
    QCheckBox* qcbPanelSolid;
    QLabel* qlPanelOpacityLabel;
    QDoubleSpinBox* qdsbPanelOpacityValue;
    QSpacerItem* qsiPanelOpacitySpacer;

    QGroupBox* qgbWindowsOpacity;
    QHBoxLayout* qhblWindowsOpacity;
    QCheckBox* qcbWindowsSolid;
    QLabel* qlWindowsOpacityLabel;
    QDoubleSpinBox* qdsbWindowsOpacityValue;
    QSpacerItem* qsiWindowsOpacitySpacer;
    
    QGroupBox *qgbUpdTime;
    QDoubleSpinBox *qdsbUpdTime;
    QSlider *qsUpdTime;
    
    QGridLayout* GeneralCfgDesignLayout;
    QSpacerItem* Spacer28;
    
    QVBoxLayout* GroupBox2Layout;

    KsensorsMain *ksensorsMain;

protected Q_SLOTS:
    virtual void languageChange();

    void slotPanelSolidToggled ( bool checked );
    void slotWindowsSolidToggled ( bool checked );
    void slotUpdateTimeSliderValue( int value );
    void slotUpdateTimeSpinValue( double value );

private:
    void addMeterSize();
};

#endif // GENERALCFGDESIGN_H
